# AddressUpdate


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**city** | **str** | The city for the billing address. | 
**country** | **str** | The country for the billing address. | 
**postal_code** | **str** | The postal code or zip code for the billing address. | 
**state** | **str** | The state, county, or province for the billing address. | 
**house_number_or_name** | **str, none_type** | The house number or name for the billing address. Not all payment services use this field but some do. | 
**line1** | **str** | The first line of the billing address. | 
**line2** | **str, none_type** | The second line of the billing address. | 
**organization** | **str, none_type** | The optional name of the company or organisation to add to the billing address. | 
**state_code** | **str, none_type** | The code of state, county, or province for the billing address in ISO 3166-2 format. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


